@@ -2,7 +2,7 @@
 This module contains all available fitting algorithms.
 These operate separately from the `Model` class.
 STRUCTURE:
-    - grad_des
+- grad_des
 """
 
 from . import np
@@ -45,7 +45,7 @@ def grad_des(get_model_pred, real_data, model_params, mu, epochs, N, samples, de
             p_samp.append(pred[sample][0] / N)
             r_samp.append(real[sample][0] / N)
 
-        if verbose:
+        if verbose:  # pragma: no cover
             print('predicted, data: ')
             print(p_samp)
             print(r_samp)
@@ -79,7 +79,7 @@ def grad_des(get_model_pred, real_data, model_params, mu, epochs, N, samples, de
 
             model_params[param] -= delta
 
-        if verbose:
+        if verbose:  # pragma: no cover
             print('Gradients: ')
             print(gradients)
             print('\n')
@@ -139,7 +139,7 @@ def tree_search(get_model_pred, real_data, model_params, param_ranges, epochs, N
                 if pair[1] < best_pair[1]:
                     best_pair = pair
 
-            if verbose:
+            if verbose:  # pragma: no cover
                 print(cost_per_value)
 
             model_params[param] = best_pair[0]
